@@ -177,12 +177,7 @@ class RetailerAPI(object):
         self.set_access_token(token["access_token"])
         return token
 
-    def refresh_access_token(
-        self,
-        username,
-        password,
-        refresh_token=None
-    ):
+    def refresh_access_token(self, username, password, refresh_token=None):
 
         if refresh_token is None and self.refresh_token is None:
             raise ValueError("No 'refresh_token' provided")
@@ -192,7 +187,7 @@ class RetailerAPI(object):
 
         params = {
             "grant_type": "refresh_token",
-            "refresh_token": refresh_token
+            "refresh_token": refresh_token,
         }
 
         resp = self.session.post(
@@ -230,9 +225,9 @@ class RetailerAPI(object):
             # If these headers are not added, the api returns a 400
             # Reference:
             #   https://api.bol.com/retailer/public/conventions/index.html
-            request_kwargs["headers"].update({
-                "content-type": "application/vnd.retailer.v3+json"
-            })
+            request_kwargs["headers"].update(
+                {"content-type": "application/vnd.retailer.v3+json"}
+            )
         resp = self.session.request(**request_kwargs)
         resp.raise_for_status()
         return resp
